# 🐦barbthroat

[![PyPI Downloads](https://img.shields.io/pypi/v/barbthroat.svg?label=PyPI)](
https://pypi.org/project/barbthroat/)

A library to help write directional strategies for [Hummingbot](https://hummingbot.org/).
